<?php
namespace Teknisa\CADEST\Services;


use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use Zeedhi\Framework\DB\StoredProcedure\Param;
use Teknisa\Model\Util\NovoCodigo;

class ImportCompService {
    protected $connection;

    public function __construct($entityManager) {
        $this->connection = $entityManager->getConnection();
        date_default_timezone_set('America/Sao_Paulo');
    }
    
    public function deleteComposicaoLocal($produto, $cdfilial, $nrorg){
        $params = array(
            ':CDPRODUTO' => $produto,
            ':CDFILIAL' => $cdfilial,
            ':NRORG'   => $nrorg
        );
        return $this->connection->executeQuery(self::DELETE_COMPOSICAO_LOCAL, $params);
    }
    
    public function deleteComposicaoPadrao($produto, $nrorg){
        $params = array(
            ':CDPRODUTO' => $produto,
            ':NRORG'   => $nrorg
        );
        return $this->connection->executeQuery(self::DELETE_COMPOSICAO_PADRAO, $params);
    }
    
    public function getComposicaoLocal($produtoOrig, $cdfilialOrig,  $nrorg){
        $paramsFrom = array(
            ':CDPRODUTO' => $produtoOrig,
            ':CDFILIAL' => $cdfilialOrig,
            ':NRORG'   => $nrorg
        );
        return $this->connection->fetchAll(self::GET_COMPOSICAO_LOCAL, $paramsFrom);
    }
    
    public function getComposicaoPadrao( $produtoOrig, $nrorg){
        $paramsFrom = array(
            ':CDPRODUTO' => $produtoOrig,
            ':NRORG'   => $nrorg
        );
        return $this->connection->fetchAll(self::GET_COMPOSICAO_PADRAO, $paramsFrom);
    }
    
    public function getComposicaoPadraoToLocal( $produto, $nrorg){
        $paramsFrom = array(
            ':CDPRODUTO' => $produto,
            ':NRORG'   => $nrorg
        );
        return $this->connection->fetchAll(self::GET_COMPOSICAO_PADRAO_TO_LOCAL, $paramsFrom);
    }
    
    public function getComposicaoLocalToPadrao($produtoOrig, $cdfilialOrig,  $nrorg){
        $paramsFrom = array(
            ':CDPRODUTO' => $produtoOrig,
            ':CDFILIAL' => $cdfilialOrig,
            ':NRORG'   => $nrorg
        );
        return $this->connection->fetchAll(self::GET_COMPOSICAO_LOCAL_TO_PADRAO, $paramsFrom);
    }
    
    public function saveComposicaoPadrao($produto, $composicao, $nrorg, $prodOrig){
        foreach ($composicao as $prodComp) {
             $params = array(
                    ":CDPRODUTO"    => $produto,
                    ":CDSUBPRODUTO" => $prodComp['CDSUBPRODUTO'],
                    ":QTSUBPRODROT" => $prodComp['QTSUBPRODROT'],
                    ":NRHRFABPROD"  => $prodComp['NRHRFABPROD'],
                    ":NRSEQPROD"    => $prodComp['NRSEQPROD'],
                    ":IDIMPPRODROT" => $prodComp['IDIMPPRODROT'],
                    ":DSAPELIDOKDS" => $prodComp['DSAPELIDOKDS'],
                    ':CDPRODIMPORT' => $prodOrig,
                    ":NRORG"        => $nrorg,
                );
            $this->connection->executeQuery(self::INSERT_COMPOSICAO_PADRAO, $params);
        }
        
    }
    
    public function saveComposicaoLocal($produto, $cdfilialDest, $composicao, $nrorg, $prodOrig){
        foreach ($composicao as $prodComp) {
            $params = array(
                    ':CDFILIAL'     => $cdfilialDest,
                    ':NRORG'        => $nrorg,
                    ':CDSUBPRODLOC' => $prodComp['CDSUBPRODLOC'],
                    ':QTSUBPRODLOC' => $prodComp['QTSUBPRODLOC'],
                    ':NRHRFABPRLOC' => $prodComp['NRHRFABPRLOC'],
                    ':NRSEQPRODLOC' => $prodComp['NRSEQPRODLOC'],
                    ':IDIMPPROTLOC' => $prodComp['IDIMPPROTLOC'],
                    ':DSAPELIDOKDS' => $prodComp['DSAPELIDOKDS'],
                    ':CDPRODIMPORT' => $prodOrig,
                    ':CDPRODUTO'    => $produto
                );
            $this->connection->executeQuery(self::INSERT_COMPOSICAO_LOCAL, $params);
        }
    }
    
    public function saveGrupoPromocionalLocal($CDFILIALDEST, $CDFILIALORIG, $NRORG, $CDPRODUTOORIG, $CDPRODUTODEST){
        $retorno = [];
        $params = array(
                    ':CDFILIAL'      => $CDFILIALDEST,
                    ':CDFILIALORIG'  => $CDFILIALORIG,
                    ':NRORG'         => $NRORG,
                    ':CDPRODUTOORIG' => $CDPRODUTOORIG,
                    ':CDPRODUTODEST' => $CDPRODUTODEST
                );
        $grupo = $this->connection->fetchAll(self::GET_GRUPO_LOCAL, $params);
        self::delGrupoDest($CDPRODUTODEST, $NRORG, $CDFILIALDEST);
        foreach ($grupo as $grupoPromocional) {
            $params['NRSEQGRPROMOFIL'] =  NovoCodigo::geraCodigo($NRORG, "GRUPROMOCPRFIL", 1, 10, false, false);
            $params['CDGRUPROMOC']       = $grupoPromocional['CDGRUPROMOC'];
            $params['QTPRGRUPPROMFIL']   = $grupoPromocional['QTPRGRUPPROMFIL'];
            $params['NRORDPROMOGRUPFIL'] = $grupoPromocional['NRORDPROMOGRUPFIL'];
            $params['CDGRUPMUTEXFIL']    = $grupoPromocional['CDGRUPMUTEXFIL'];
            $params['QTPRGRUPROMINFIL']  = $grupoPromocional['QTPRGRUPROMINFIL'];
            $params['IDIMPGRPROMOFIL']  = $grupoPromocional['IDIMPGRPROMOFIL'];
            $params['DTINIVGGRPROFIL']  = $grupoPromocional['DTINIVGGRPROFIL'];
            $params['DTFINVGGRPROFIL']  = $grupoPromocional['DTFINVGGRPROFIL'];
            $params['IDAPLICADESCFIL']  = $grupoPromocional['IDAPLICADESCFIL'];
            
            
            $retorno = $this->connection->executeQuery(self::INSERT_GRUPO_LOCAL, $params);
            $DESCONTO =  $this->connection->fetchAll(self::GET_DESCONTO_LOCAL, $params);
            
            if($DESCONTO){
                foreach ($DESCONTO as $value) {
                    $params['CDPRODPROMOCAO'] = $value['CDPRODPROMOCAO'];
                    $params['CDGRUPROMOC'] = $value['CDGRUPROMOC'];
                    $params['CDPRODUTO'] = $value['CDPRODUTO'];
                    $params['IDPERVALDESFIL'] = $value['IDPERVALDESFIL'];
                    $params['VRDESPRPROMOFIL'] = $value['VRDESPRPROMOFIL'];
                    $params['DTULTATUDESPRFI'] = $value['DTULTATUDESPRFI'];
                    $params['IDAPLICADESCPRFI'] = $value['IDAPLICADESCPRFI'];
                    $params['IDPRODPRESELFIL'] = $value['IDPRODPRESELFIL'];
                    $params['IDOBRPRODSELFIL'] = $value['IDOBRPRODSELFIL'];
                    $params['IDDESCACRPROFIL'] = $value['IDDESCACRPROFIL'];
                    $params['IDPRINCPROD']     = $value['IDPRINCPROD'];
                    $this->connection->executeQuery(self::INSERT_DESCONTO_LOCAL, $params);
                }
            }
        }
        return $retorno;
    }
    
    public function delGrupoDest($CDPRODUTODEST, $NRORG, $CDFILIAL){
        if($CDFILIAL){
            $params = array(
                    ':NRORG'         => $NRORG,
                    ':CDFILIALORIG'  => $CDFILIAL,
                    ':CDPRODUTOORIG' => $CDPRODUTODEST,
                    ':CDPRODUTODEST' => $CDPRODUTODEST
                ); 
            $grupo = $this->connection->fetchAll(self::GET_GRUPO_LOCAL, $params);
            foreach ($grupo as $grupoPromocional) {
                $params['CDGRUPROMOC'] = $grupoPromocional['CDGRUPROMOC'];
                $this->connection->executeQuery(self::DELETE_FILHO_LOCAL, $params); 
                $this->connection->executeQuery(self::DELETE_GRUPO_LOCAL, $params); 
            }
            
        } else {
           $params = array(
                    ':NRORG'         => $NRORG,
                    ':CDPRODUTOORIG' => $CDPRODUTODEST,
                    ':CDPRODUTODEST' => $CDPRODUTODEST
                ); 
            $grupo = $this->connection->fetchAll(self::GET_GRUPO_PADRAO, $params);
            foreach ($grupo as $grupoPromocional) {
                $params['CDGRUPROMOC'] = $grupoPromocional['CDGRUPROMOC'];
                $this->connection->executeQuery(self::DELETE_FILHO_PADRAO, $params); 
                $this->connection->executeQuery(self::DELETE_GRUPO_PADRAO, $params); 
            }
        }
    }
    
    public function saveGrupoPromocionalPadrao($NRORG, $CDPRODUTOORIG, $CDPRODUTODEST){
        $params = array(
                    ':NRORG'         => $NRORG,
                    ':CDPRODUTOORIG' => $CDPRODUTOORIG,
                    ':CDPRODUTODEST' => $CDPRODUTODEST
                );
        self::delGrupoDest($CDPRODUTODEST, $NRORG, null);
        $grupo = $this->connection->fetchAll(self::GET_GRUPO_PADRAO, $params);
        $retorno = [];
        foreach ($grupo as $grupoPromocional) {
            $params['NRSEQGRPROMO'] =  NovoCodigo::geraCodigo($NRORG, "GRUPROMOCPROD", 1, 10, false, false);
            $params['CDGRUPROMOC']       = $grupoPromocional['CDGRUPROMOC'];
            $params['QTPRGRUPPROMOC']   = $grupoPromocional['QTPRGRUPPROMOC'];
            $params['NRORDPROMOGRUP'] = $grupoPromocional['NRORDPROMOGRUP'];
            $params['CDGRUPMUTEX']    = $grupoPromocional['CDGRUPMUTEX'];
            $params['QTPRGRUPROMIN']  = $grupoPromocional['QTPRGRUPROMIN'];
            $params['IDIMPGRPROMO']  = $grupoPromocional['IDIMPGRPROMO'];
            
            $params['DTINIVGGRPROMO']  = $grupoPromocional['DTINIVGGRPROMO'];
            $params['DTFINVGGRPROMO']  = $grupoPromocional['DTFINVGGRPROMO'];
            $params['IDAPLICADESC']  = $grupoPromocional['IDAPLICADESC'];
            
            
            $retorno = $this->connection->executeQuery(self::INSERT_GRUPO_PADRAO, $params);
            $DESCONTO =  $this->connection->fetchAll(self::GET_DESCONTO_PADRAO, $params);
            if($DESCONTO){
                foreach ($DESCONTO as $value) {
                    $params['CDPRODPROMOCAO'] = $value['CDPRODPROMOCAO'];
                    $params['CDGRUPROMOC'] = $value['CDGRUPROMOC'];
                    $params['CDPRODUTO'] = $value['CDPRODUTO'];
                    $params['IDPERVALORDES'] = $value['IDPERVALORDES'];
                    $params['VRDESPRODPROMOC'] = $value['VRDESPRODPROMOC'];
                    $params['DTULTATUDESPR'] = $value['DTULTATUDESPR'];
                    $params['IDAPLICADESCPR'] = $value['IDAPLICADESCPR'];
                    $params['IDPRODPRESELEC'] = $value['IDPRODPRESELEC'];
                    $params['IDOBRPRODSELEC'] = $value['IDOBRPRODSELEC'];
                    $params['IDDESCACRPROMO'] = $value['IDDESCACRPROMO'];
                    $params['IDPRINCPROD']     = $value['IDPRINCPROD'];
                    $this->connection->executeQuery(self::INSERT_DESCONTO_PADRAO, $params);
                }
            }
        }
        return $retorno;
    }
    
    public function saveGrupoPromocionalPadraoToLocal($NRORG, $CDPRODUTO, $CDFILIAL){
        $params = array(
                    ':NRORG'         => $NRORG,
                    ':CDPRODUTOORIG' => $CDPRODUTO,
                    ':CDPRODUTODEST' => $CDPRODUTO,
                    ':CDFILIAL' => $CDFILIAL
                );
        self::delGrupoDest($CDPRODUTO, $NRORG, $CDFILIAL);
        $grupo = $this->connection->fetchAll(self::GET_GRUPO_PADRAO, $params);
        $retorno = [];
        foreach ($grupo as $grupoPromocional) {
            $params['NRSEQGRPROMOFIL'] =  NovoCodigo::geraCodigo($NRORG, "GRUPROMOCPRFIL", 1, 10, false, false);
            $params['CDGRUPROMOC']       = $grupoPromocional['CDGRUPROMOC'];
            $params['QTPRGRUPPROMFIL']   = $grupoPromocional['QTPRGRUPPROMOC'];
            $params['NRORDPROMOGRUPFIL'] = $grupoPromocional['NRORDPROMOGRUP'];
            $params['CDGRUPMUTEXFIL']    = $grupoPromocional['CDGRUPMUTEX'];
            $params['QTPRGRUPROMINFIL']  = $grupoPromocional['QTPRGRUPROMIN'];
            $params['IDIMPGRPROMOFIL']  = $grupoPromocional['IDIMPGRPROMO'];
            $params['DTINIVGGRPROFIL']  = $grupoPromocional['DTINIVGGRPROMO'];
            $params['DTFINVGGRPROFIL']  = $grupoPromocional['DTFINVGGRPROMO'];
            $params['IDAPLICADESCFIL']  = $grupoPromocional['IDAPLICADESC'];
           
            
            
            $retorno = $this->connection->executeQuery(self::INSERT_GRUPO_LOCAL, $params);
            $DESCONTO =  $this->connection->fetchAll(self::GET_DESCONTO_PADRAO, $params);
            
            if($DESCONTO){
                foreach ($DESCONTO as $value) {
                    $params['CDPRODPROMOCAO'] = $value['CDPRODPROMOCAO'];
                    $params['CDGRUPROMOC'] = $value['CDGRUPROMOC'];
                    $params['CDPRODUTO'] = $value['CDPRODUTO'];
                    $params['IDPERVALDESFIL'] = $value['IDPERVALORDES'];
                    $params['VRDESPRPROMOFIL'] = $value['VRDESPRODPROMOC'];
                    $params['DTULTATUDESPRFI'] = $value['DTULTATUDESPR'];
                    $params['IDAPLICADESCPRFI'] = $value['IDAPLICADESCPR'];
                    $params['IDPRODPRESELFIL'] = $value['IDPRODPRESELEC'];
                    $params['IDOBRPRODSELFIL'] = $value['IDOBRPRODSELEC'];
                    $params['IDDESCACRPROFIL'] = $value['IDDESCACRPROMO'];
                    $params['IDPRINCPROD']     = $value['IDPRINCPROD'];
                    
                    
                    $this->connection->executeQuery(self::INSERT_DESCONTO_LOCAL, $params);
                }
            }
        }
        return $retorno;
    }
    
    public function saveGrupoPromocionalLocalToPadrao($CDFILIAL, $NRORG, $CDPRODUTO){
        $retorno = [];
        $params = array(
                    ':CDFILIAL'      => $CDFILIAL,
                    ':NRORG'         => $NRORG,
                    ':CDPRODUTOORIG' => $CDPRODUTO,
                    ':CDPRODUTODEST' => $CDPRODUTO,
                    ':CDFILIALORIG'  => $CDFILIAL,
                    ':CDPRODUTO'     => $CDPRODUTO
                );
        self::delGrupoDest($CDPRODUTO, $NRORG, null);
        $grupo = $this->connection->fetchAll(self::GET_GRUPO_LOCAL, $params);
        foreach ($grupo as $grupoPromocional) {
            $params['NRSEQGRPROMO'] =  NovoCodigo::geraCodigo($NRORG, "GRUPROMOCPROD", 1, 10, false, false);
            $params['CDGRUPROMOC']    = $grupoPromocional['CDGRUPROMOC'];
            $params['QTPRGRUPPROMOC'] = $grupoPromocional['QTPRGRUPPROMFIL'];
            $params['NRORDPROMOGRUP'] = $grupoPromocional['NRORDPROMOGRUPFIL'];
            $params['CDGRUPMUTEX']    = $grupoPromocional['CDGRUPMUTEXFIL'];
            $params['QTPRGRUPROMIN']  = $grupoPromocional['QTPRGRUPROMINFIL'];
            $params['IDIMPGRPROMO']  = $grupoPromocional['IDIMPGRPROMOFIL'];
            $params['DTINIVGGRPROMO']  = $grupoPromocional['DTINIVGGRPROFIL'];
            $params['DTFINVGGRPROMO']  = $grupoPromocional['DTFINVGGRPROFIL'];
            $params['IDAPLICADESC']  = $grupoPromocional['IDAPLICADESCFIL'];
            
            $retorno = $this->connection->executeQuery(self::INSERT_GRUPO_PADRAO, $params);
            $DESCONTO =  $this->connection->fetchAll(self::GET_DESCONTO_LOCAL, $params);
            if($DESCONTO){
                foreach ($DESCONTO as $value) {
                    $params['CDPRODPROMOCAO'] = $value['CDPRODPROMOCAO'];
                    $params['CDGRUPROMOC'] = $value['CDGRUPROMOC'];
                    $params['CDPRODUTO'] = $value['CDPRODUTO'];
                    $params['IDPERVALORDES'] = $value['IDPERVALDESFIL'];
                    $params['VRDESPRODPROMOC'] = $value['VRDESPRPROMOFIL'];
                    $params['DTULTATUDESPR'] = $value['DTULTATUDESPRFI'];
                    $params['IDAPLICADESCPR'] = $value['IDAPLICADESCPRFI'];
                    $params['IDPRODPRESELEC'] = $value['IDPRODPRESELFIL'];
                    $params['IDOBRPRODSELEC'] = $value['IDOBRPRODSELFIL'];
                    $params['IDDESCACRPROMO'] = $value['IDDESCACRPROFIL'];
                    $params['IDPRINCPROD'] = $value['IDPRINCPROD'];
                    $this->connection->executeQuery(self::INSERT_DESCONTO_PADRAO, $params);
                }
            }
        }
        return $retorno;
    }
    
    public function findPadrao (){
        $params = array();
        return $this->connection->fetchAll(self::GET_PROD_PADRAO, $params);
    }
    
    public function findLocal ($cdfilial){
        $params = array(
            ':CDFILIAL' => $cdfilial    
        );
        return $this->connection->fetchAll(self::GET_PROD_LOCAL, $params);
    }
    
    public function checkComposicaoOrigL($composicao, $cdfilialOrig,  $nrorg, $produto, &$flag){
        foreach ($composicao as $produtoComp) {
            if($produto == $produtoComp['CDPRODUTO']){
                $flag = false;
                return false;
            }
            $composicaoFilha = self::getComposicaoLocal($produtoComp['CDPRODUTO'], $cdfilialOrig, $nrorg);
            if(count($composicaoFilha) > 0){
                self::checkComposicaoOrigL($composicaoFilha, $cdfilialOrig,  $nrorg, $produtoComp['CDPRODUTO'], $flag);
            }
        }
    }
    
    public function checkComposicaoOrigP($composicao,  $nrorg, $produto, &$flag){
        foreach ($composicao as $produtoComp) {
            if($produto == $produtoComp['CDPRODUTO']){
                $flag = false;
                return false;
            }
            $composicaoFilha = self::getComposicaoPadrao($produtoComp['CDPRODUTO'], $nrorg);
            if(count($composicaoFilha) > 0){
                self::checkComposicaoOrigP($composicaoFilha,  $nrorg, $produtoComp['CDPRODUTO'], $flag);
            }
        }
    }
    
    const GET_GRUPO_PADRAO = "
        SELECT  CDPRODPROMOCAO,   CDGRUPROMOC, QTPRGRUPPROMOC, NRORDPROMOGRUP, CDGRUPMUTEX, QTPRGRUPROMIN, IDIMPGRPROMO, DTINIVGGRPROMO, DTFINVGGRPROMO, IDAPLICADESC
        FROM GRUPROMOCPROD 
                WHERE  CDPRODPROMOCAO = :CDPRODUTOORIG 
                    AND NRORG = :NRORG
    ";
    
    const DELETE_GRUPO_PADRAO = '
    DELETE FROM GRUPROMOCPROD 
        WHERE CDGRUPROMOC = :CDGRUPROMOC 
        AND CDPRODPROMOCAO = :CDPRODUTODEST
        AND NRORG = :NRORG';
        
    const DELETE_FILHO_PADRAO = '
    DELETE FROM DESGRUPROMOCPR 
        WHERE CDGRUPROMOC = :CDGRUPROMOC 
        AND CDPRODPROMOCAO = :CDPRODUTODEST
        AND NRORG = :NRORG';
        
    const INSERT_GRUPO_PADRAO = '
    INSERT INTO GRUPROMOCPROD (  CDPRODPROMOCAO,   CDGRUPROMOC, NRSEQGRPROMO, QTPRGRUPPROMOC, NRORDPROMOGRUP, CDGRUPMUTEX, QTPRGRUPROMIN, IDIMPGRPROMO, DTINIVGGRPROMO, DTFINVGGRPROMO, IDAPLICADESC)
    VALUES ( :CDPRODUTODEST, :CDGRUPROMOC, :NRSEQGRPROMO, :QTPRGRUPPROMOC, :NRORDPROMOGRUP, :CDGRUPMUTEX, :QTPRGRUPROMIN, :IDIMPGRPROMO, :DTINIVGGRPROMO, :DTFINVGGRPROMO, :IDAPLICADESC)
    ';
    
    const INSERT_GRUPO_LOCAL = "
    INSERT INTO GRUPROMOCPRFIL (CDFILIAL,  CDPRODPROMOCAO,   CDGRUPROMOC, NRSEQGRPROMOFIL, QTPRGRUPPROMFIL, NRORDPROMOGRUPFIL, CDGRUPMUTEXFIL, QTPRGRUPROMINFIL, IDIMPGRPROMOFIL, DTFINVGGRPROFIL, DTINIVGGRPROFIL, IDAPLICADESCFIL)
    VALUES (:CDFILIAL, :CDPRODUTODEST, :CDGRUPROMOC, :NRSEQGRPROMOFIL, :QTPRGRUPPROMFIL, :NRORDPROMOGRUPFIL, :CDGRUPMUTEXFIL, :QTPRGRUPROMINFIL, :IDIMPGRPROMOFIL, :DTFINVGGRPROFIL, :DTINIVGGRPROFIL, :IDAPLICADESCFIL)";
    
    const GET_GRUPO_LOCAL = "
        SELECT   CDFILIAL,  CDPRODPROMOCAO,   CDGRUPROMOC, QTPRGRUPPROMFIL, NRORDPROMOGRUPFIL, CDGRUPMUTEXFIL, QTPRGRUPROMINFIL, IDIMPGRPROMOFIL, DTFINVGGRPROFIL, DTINIVGGRPROFIL, IDAPLICADESCFIL
        FROM GRUPROMOCPRFIL 
                WHERE  CDPRODPROMOCAO = :CDPRODUTOORIG 
                    AND NRORG = :NRORG 
                    AND CDFILIAL = :CDFILIALORIG
    ";
    
        const INSERT_DESCONTO_PADRAO = "
    INSERT INTO DESGRUPROMOCPR 
        ( CDPRODPROMOCAO, CDGRUPROMOC, CDPRODUTO, NRSEQGRPROMO, IDPERVALORDES, VRDESPRODPROMOC, DTULTATUDESPR, IDAPLICADESCPR, IDPRODPRESELEC, IDOBRPRODSELEC, IDDESCACRPROMO, IDPRINCPROD, NRORG)
    VALUES 
        ( :CDPRODUTODEST, :CDGRUPROMOC, :CDPRODUTO, :NRSEQGRPROMO, :IDPERVALORDES, :VRDESPRODPROMOC, :DTULTATUDESPR, :IDAPLICADESCPR, :IDPRODPRESELEC, :IDOBRPRODSELEC, :IDDESCACRPROMO, :IDPRINCPROD, :NRORG)
        ";
    
    const GET_DESCONTO_PADRAO = "
    SELECT CDPRODPROMOCAO, CDGRUPROMOC, CDPRODUTO, IDPERVALORDES, VRDESPRODPROMOC, DTULTATUDESPR, IDAPLICADESCPR, IDPRODPRESELEC, IDOBRPRODSELEC, IDDESCACRPROMO, IDPRINCPROD
    FROM DESGRUPROMOCPR 
        WHERE  CDPRODPROMOCAO = :CDPRODUTOORIG 
        AND CDGRUPROMOC = :CDGRUPROMOC"; 
        
    const INSERT_DESCONTO_LOCAL = "
    INSERT INTO DESGRUPROMPRFIL 
        (CDFILIAL, CDPRODPROMOCAO, NRSEQGRPROMOFIL, CDGRUPROMOC, CDPRODUTO, IDPERVALDESFIL, VRDESPRPROMOFIL, IDPRINCPROD,
        DTULTATUDESPRFI, IDAPLICADESCPRFI, IDPRODPRESELFIL, IDOBRPRODSELFIL, IDDESCACRPROFIL, NRORG)
    VALUES 
        (:CDFILIAL, :CDPRODUTODEST, :NRSEQGRPROMOFIL, :CDGRUPROMOC, :CDPRODUTO, :IDPERVALDESFIL, :VRDESPRPROMOFIL, :IDPRINCPROD,
        :DTULTATUDESPRFI, :IDAPLICADESCPRFI, :IDPRODPRESELFIL, :IDOBRPRODSELFIL, :IDDESCACRPROFIL, :NRORG)
        ";
    
    const GET_DESCONTO_LOCAL = "
    SELECT CDFILIAL, CDPRODPROMOCAO, CDGRUPROMOC, CDPRODUTO, IDPERVALDESFIL, VRDESPRPROMOFIL, DTULTATUDESPRFI, IDAPLICADESCPRFI, IDPRODPRESELFIL, IDOBRPRODSELFIL, IDDESCACRPROFIL,IDPRINCPROD 
    FROM DESGRUPROMPRFIL 
        WHERE CDFILIAL = :CDFILIALORIG 
        AND CDPRODPROMOCAO = :CDPRODUTOORIG 
        AND CDGRUPROMOC = :CDGRUPROMOC";
    
              
         const DELETE_FILHO_LOCAL = '
    DELETE FROM DESGRUPROMPRFIL 
        WHERE CDGRUPROMOC = :CDGRUPROMOC 
        AND CDPRODPROMOCAO = :CDPRODUTODEST 
        AND NRORG = :NRORG
        AND CDFILIAL = :CDFILIALORIG';
    
    const DELETE_COMPOSICAO_LOCAL = 
        "DELETE ROTFABLOCAL 
            WHERE CDFILIAL     = :CDFILIAL 
              AND CDPRODUTO    = :CDPRODUTO
              AND NRORG        = :NRORG";
              
    const DELETE_GRUPO_LOCAL = '
    DELETE FROM GRUPROMOCPRFIL 
        WHERE CDGRUPROMOC = :CDGRUPROMOC 
        AND CDPRODPROMOCAO = :CDPRODUTODEST 
        AND NRORG = :NRORG
        AND CDFILIAL = :CDFILIALORIG';
              
    const DELETE_COMPOSICAO_PADRAO = 
        "DELETE ROTFABRICA 
            WHERE  CDPRODUTO    = :CDPRODUTO
              AND NRORG        = :NRORG";
              
    const INSERT_COMPOSICAO_LOCAL = "
        INSERT INTO ROTFABLOCAL 
            (CDFILIAL, NRORG, CDPRODUTO, CDSUBPRODLOC,
             QTSUBPRODLOC, NRHRFABPRLOC, NRSEQPRODLOC, IDIMPPROTLOC,
             DSAPELIDOKDS, CDPRODIMPORT)
        VALUES
            (:CDFILIAL, :NRORG, :CDPRODUTO, :CDSUBPRODLOC,
             :QTSUBPRODLOC, :NRHRFABPRLOC, :NRSEQPRODLOC, :IDIMPPROTLOC,
             :DSAPELIDOKDS, :CDPRODIMPORT)
    ";
              
    const INSERT_COMPOSICAO_PADRAO = 
        "INSERT INTO ROTFABRICA 
            ( CDPRODUTO, CDSUBPRODUTO, QTSUBPRODROT,
              NRHRFABPROD, NRSEQPROD, IDIMPPRODROT,  DSAPELIDOKDS, NRORG, CDPRODIMPORT)
            VALUES
            ( :CDPRODUTO, :CDSUBPRODUTO, :QTSUBPRODROT,
              :NRHRFABPROD, :NRSEQPROD, :IDIMPPRODROT,
               :DSAPELIDOKDS, :NRORG, :CDPRODIMPORT)";
  
              
    const GET_COMPOSICAO_LOCAL = "
        SELECT R.CDFILIAL ,
          R.NRORG,
          P.CDPRODUTO ,
          P.CDARVPROD ,
          R.CDSUBPRODLOC,
          R.QTSUBPRODLOC,
          R.NRHRFABPRLOC,
          R.NRSEQPRODLOC,
          R.IDIMPPROTLOC,
          P.NMPRODUTO ,
          P.SGUNIDADE ,
          F.NRCOMPPROD ,
          R.CDDEPTO ,
          D.NMDEPTO ,
          R.DSAPELIDOKDS
        FROM ROTFABLOCAL R,
          PRODUTO P,
          DEPARTAMENTO D,
          (SELECT COUNT(*) AS NRCOMPPROD,
            CDPRODUTO
          FROM ROTFABLOCAL
          WHERE CDFILIAL = :CDFILIAL
          GROUP BY CDPRODUTO
          )F
        WHERE R.CDFILIAL   = :CDFILIAL
        AND R.CDPRODUTO    = :CDPRODUTO
        AND P.CDPRODUTO    = R.CDSUBPRODLOC
        AND F.CDPRODUTO(+) = R.CDSUBPRODLOC
        AND D.CDDEPTO(+)   = R.CDDEPTO
        AND R.NRORG        = P.NRORG
        AND D.NRORG(+)     = R.NRORG
        ORDER BY R.NRSEQPRODLOC
    ";
        
    const GET_COMPOSICAO_LOCAL_TO_PADRAO = "
        SELECT R.CDFILIAL, R.NRORG, P.CDPRODUTO, P.CDARVPROD, R.CDSUBPRODLOC AS CDSUBPRODUTO, R.QTSUBPRODLOC AS QTSUBPRODROT, R.NRHRFABPRLOC AS NRHRFABPROD, R.NRSEQPRODLOC AS NRSEQPROD, 
               R.IDIMPPROTLOC AS IDIMPPRODROT, P.NMPRODUTO, P.SGUNIDADE, F.NRCOMPPROD, R.CDDEPTO, D.NMDEPTO, R.DSAPELIDOKDS
          FROM ROTFABLOCAL R, PRODUTO P, DEPARTAMENTO D, (SELECT COUNT(*) AS NRCOMPPROD, CDPRODUTO FROM ROTFABLOCAL WHERE CDFILIAL = :CDFILIAL GROUP BY CDPRODUTO )F
         WHERE R.CDFILIAL   = :CDFILIAL
           AND R.CDPRODUTO    = :CDPRODUTO
           AND P.CDPRODUTO    = R.CDSUBPRODLOC
           AND F.CDPRODUTO(+) = R.CDSUBPRODLOC
           AND D.CDDEPTO(+)   = R.CDDEPTO
           AND R.NRORG        = P.NRORG
           AND D.NRORG(+)     = R.NRORG
        ORDER BY R.NRSEQPRODLOC
    ";
        
    const GET_COMPOSICAO_PADRAO = "
    SELECT A.CDPRODUTO, A.CDARVPROD, A.CDSUBPRODUTO, A.QTSUBPRODROT, A.NRHRFABPROD, A.NRSEQPROD, A.IDIMPPRODROT, A.NMPRODUTO, A.SGUNIDADE,
           A.NRCOMPPROD, A.IDSUBPROD, A.CDDEPTO, A.NMDEPTO, A.DSAPELIDOKDS, CDGRUPOCOMP, NMGRUPOCOMP, A.NRORG
    FROM (SELECT P.CDPRODUTO, P.NRORG, P.CDARVPROD, R.CDSUBPRODUTO, R.QTSUBPRODROT, R.NRHRFABPROD, R.NRSEQPROD, R.IDIMPPRODROT, P.NMPRODUTO, P.SGUNIDADE,
                 NVL(F.NRCOMPPROD, 0) AS NRCOMPPROD, R.CDDEPTO, D.NMDEPTO, R.DSAPELIDOKDS, COUNT(R.CDSUBPRODUTO) AS IDSUBPROD, G.CDGRUPOCOMP, G.NMGRUPOCOMP
            FROM ROTFABRICA R, PRODUTO P, DEPARTAMENTO D, (SELECT COUNT(*) AS NRCOMPPROD, CDPRODUTO FROM ROTFABRICA GROUP BY CDPRODUTO ) F, GRUPOCOMP G
      WHERE R.CDPRODUTO    = :CDPRODUTO
      AND D.CDDEPTO(+)     = R.CDDEPTO
      AND R.CDSUBPRODUTO   = P.CDPRODUTO
      AND F.CDPRODUTO(+)   = R.CDSUBPRODUTO
      AND G.CDGRUPOCOMP(+) = R.CDGRUPOCOMP
      GROUP BY P.CDPRODUTO, P.CDARVPROD, R.CDSUBPRODUTO, R.QTSUBPRODROT, R.NRHRFABPROD, R.NRSEQPROD, R.IDIMPPRODROT, P.NMPRODUTO, P.SGUNIDADE, F.NRCOMPPROD,
               R.CDDEPTO, D.NMDEPTO, R.DSAPELIDOKDS, G.CDGRUPOCOMP, G.NMGRUPOCOMP, P.NRORG ) A
    ORDER BY A.NRSEQPROD";
    
    const GET_PROD_PADRAO = "
    SELECT DISTINCT R.CDPRODUTO, P.NMPRODUTO, P.CDARVPROD
        FROM ROTFABRICA R 
        JOIN PRODUTO P ON
        P.CDPRODUTO = R.CDPRODUTO ";
        
    const GET_PROD_LOCAL = "
    SELECT DISTINCT R.CDPRODUTO, P.NMPRODUTO,  P.CDARVPROD
        FROM ROTFABLOCAL R 
        JOIN PRODUTO P ON
        P.CDPRODUTO = R.CDPRODUTO AND
        R.CDFILIAL = :CDFILIAL";
        
    const GET_COMPOSICAO_PADRAO_TO_LOCAL = "
        SELECT A.CDPRODUTO, A.CDARVPROD, A.CDSUBPRODUTO AS CDSUBPRODLOC, A.QTSUBPRODROT AS QTSUBPRODLOC, A.NRHRFABPROD AS NRHRFABPRLOC, A.NRSEQPROD AS NRSEQPRODLOC, 
               A.IDIMPPRODROT AS IDIMPPROTLOC, A.NMPRODUTO, A.SGUNIDADE, A.NRCOMPPROD, A.IDSUBPROD, A.CDDEPTO, A.NMDEPTO, A.DSAPELIDOKDS, CDGRUPOCOMP, NMGRUPOCOMP, A.NRORG
        FROM (SELECT P.CDPRODUTO, P.NRORG, P.CDARVPROD, R.CDSUBPRODUTO, R.QTSUBPRODROT, R.NRHRFABPROD, R.NRSEQPROD, R.IDIMPPRODROT, P.NMPRODUTO, P.SGUNIDADE,
                     NVL(F.NRCOMPPROD, 0) AS NRCOMPPROD, R.CDDEPTO, D.NMDEPTO, R.DSAPELIDOKDS, COUNT(R.CDSUBPRODUTO) AS IDSUBPROD, G.CDGRUPOCOMP, G.NMGRUPOCOMP
                FROM ROTFABRICA R, PRODUTO P, DEPARTAMENTO D, (SELECT COUNT(*) AS NRCOMPPROD, CDPRODUTO FROM ROTFABRICA GROUP BY CDPRODUTO ) F, GRUPOCOMP G
          WHERE R.CDPRODUTO    = :CDPRODUTO
          AND D.CDDEPTO(+)     = R.CDDEPTO
          AND R.CDSUBPRODUTO   = P.CDPRODUTO
          AND F.CDPRODUTO(+)   = R.CDSUBPRODUTO
          AND G.CDGRUPOCOMP(+) = R.CDGRUPOCOMP
          GROUP BY P.CDPRODUTO, P.CDARVPROD, R.CDSUBPRODUTO, R.QTSUBPRODROT, R.NRHRFABPROD, R.NRSEQPROD, R.IDIMPPRODROT, P.NMPRODUTO, P.SGUNIDADE, F.NRCOMPPROD,
                   R.CDDEPTO, D.NMDEPTO, R.DSAPELIDOKDS, G.CDGRUPOCOMP, G.NMGRUPOCOMP, P.NRORG ) A
        ORDER BY A.NRSEQPROD
    ";
    
}